&nbsp;

<div align="center">
<img src="project_images/csm_ritsch_slider_796236face.jpg" width=150%>

<div style="color: aquamarine" href="https://www.oeaw.ac.at/detail/news/qutrit-complex-quantum-teleportation-achieved-for-the-first-time-1"><b>IMAGE REFERENCE</b></div>

[![Unitary Fund](https://img.shields.io/badge/Supported%20By-UNITARY%20FUND-brightgreen.svg?style=for-the-badge)](https://unitary.fund)
# Qutritium
</div>

## What is Qutritium?
It is a Python package that provides qutrit processing techniques such as calibration and decomposition, etc (not exclusive).

Qutritium enables students researchers to run a qutrit system on available quantum computers which mainly comes from IBM cloud quantum computers.

## 📦 Installation

**Qutritium** runs in python environment. User can download newest python released **[here](https://www.python.org/downloads/)**.\
Recommendation: **[Anaconda](https://www.anaconda.com/products/distribution)** for environment separation

```bash
  pip install qutritium
```

## ✅ Qutritium Available Functions

| Protocol        | Purpose and functionalities |
|-----------------|-----------------------------|
| Calibration     | ...                         |
| Virtual Machine | ...                         |
 | Decomposition   | ...                         | 

## ✍️ Usage/Examples

```python
from qutritium.calibration import TR01

```

## 👥 Authors

- **[Son Pham](https://github.com/spham1611)**
- **[Tien Nguyen](https://github.com/ngdnhtien)**
- **[Bao Bach](https://github.com/bachbao)**

## 🧾License

[MIT License](LICENSE.txt)


## 📌 Documentation

[Documentation](https://spham1611.github.io/qutritium/)


